"use client";

import { AccountInfo } from "@/components/account-info";
import { UserDataContext } from "@/components/providers/userdata-provider";
import { Skeleton } from "@/components/ui/skeleton";
import type { IUserData } from "@/interfaces/userdata.interface";
import {
	type Dispatch,
	type SetStateAction,
	useContext,
	useEffect,
	useState,
} from "react";

export function AccountDialog() {
	const userContext = useContext(UserDataContext);
	const [isLoaded, setIsLoaded] = useState<boolean>(false);

	if (!userContext?.userData) {
		userContext?.setUserData({
			firstName: "Mathis",
			lastName: "Herriot",
			age: 23,
			city: "Chambéry",
			created_at: "jaj",
			dollarAvailables: 34,
			email: "mherriot@tutanota.com",
			id: "098807e1-6681-407a-a2b4-e6b7e5ec1919",
			isActive: true,
			pseudo: "Avnyr",
			roleId: "092fb1eb-4ce4-4e3e-9df1-d00d467c6a43",
			updated_at: "",
			wallet: {
				uat: Date.now(),
				update_interval: 30_000,
				owned_cryptos: [
					{
						id: "1c237bcc-d2fa-4c4b-9a3a-f0efb4569e1e",
						name: "Spectral",
						value: 1.61051,
						image:
							"https://images.unsplash.com/photo-1640833906651-6bd1af7aeea3?w=800&auto=format&fit=crop&q=60&ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxzZWFyY2h8MTh8fGNyeXB0b3xlbnwwfHwwfHx8MA%3D%3D",
						quantity: 999,
						created_at: "2024-06-08T22:42:14.113Z",
						updated_at: "2024-06-11T12:48:07.001Z",
					},
					{
						id: "6c0edc95-a968-4c2f-9169-33acfdc73575",
						name: "SOL",
						value: 30.91268053287073,
						image:
							"https://images.unsplash.com/photo-1523961131990-5ea7c61b2107?w=500&auto=format&fit=crop&q=60&ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxzZWFyY2h8Nnx8Y3J5cHRvfGVufDB8fDB8fHww",
						quantity: 998,
						created_at: "2024-06-07T09:30:31.282Z",
						updated_at: "2024-06-08T23:44:54.242Z",
					},
				],
			},
		});
	}

	useEffect(() => {
		if (userContext?.userData) {
			setIsLoaded(true);
		}
	}, [userContext?.userData]);

	if (!isLoaded) {
		return <Skeleton className="w-14 h-10 rounded" />;
	}

	return (
		<div>
			<AccountInfo
				userData={userContext?.userData as IUserData}
				setUserData={
					userContext?.setUserData as Dispatch<SetStateAction<IUserData | undefined>>
				}
			/>
		</div>
	);
}
