"use client";
import { Button } from "@/components/ui/button";
import {
	Dialog,
	DialogContent,
	DialogDescription,
	DialogFooter,
	DialogHeader,
	DialogTitle,
	DialogTrigger,
} from "@/components/ui/dialog";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import type { IUserData } from "@/interfaces/userdata.interface";

import { CopyButton } from "@/components/ui/copy-button";
import {Bitcoin, Fingerprint, Landmark, RefreshCw, Unplug, User, Wallet} from "lucide-react";
import type React from "react";
import {useState} from "react";
import {refreshUserData} from "@/services/account.handler";

export function AccountInfo({
	userData,
	setUserData,
}: {
	userData: IUserData;
	setUserData: React.Dispatch<React.SetStateAction<IUserData | undefined>>;
}) {

	const [refreshOngoing, setRefreshOngoing] = useState<boolean>(false)
	
	function doingRefresh() {
		setRefreshOngoing(true);
		refreshUserData().then(()=>setRefreshOngoing(false))
	}

	return (
		<Dialog>
			<DialogTrigger asChild>
				<Button variant="outline" className={"gap-2 px-2"}>
					<p>{userData.firstName}</p>
					<User />
				</Button>
			</DialogTrigger>
			<DialogContent className="sm:max-w-[425px]">
				<DialogHeader>
					<DialogTitle>{`${userData.firstName} ${userData.lastName}`}</DialogTitle>
					<DialogDescription>Your personal account data.</DialogDescription>
				</DialogHeader>
				<div className={"flex flex-col items-center justify-center w-full"}>
					<div className={"flex flex-col justify-evenly items-center gap-2"}>
						<div
							className={
								"flex flex-col md:flex-row gap-2 justify-center md:justify-evenly items-start md:items-center w-full"
							}
						>
							<div
								className={
									"flex gap-1 justify-start md:justify-center items-center mx-auto w-full md:w-fit"
								}
							>
								<Landmark />
								<p className={"rounded bg-accent text-accent-foreground p-1"}>
									{userData.dollarAvailables} $
								</p>
							</div>
							<div
								className={
									"flex gap-1 justify-start md:justify-center items-center mx-auto w-full md:w-fit"
								}
							>
								<Bitcoin />
								<p className={"rounded bg-accent text-accent-foreground p-1"}>
									You dont have cryptos.
								</p>
							</div>
						</div>
						<div
							className={"flex flex-col gap-3 justify-center items-start mx-auto mt-4"}
						>
							<div className={"flex flex-row text-nowrap flex-nowrap gap-1 text-primary"}>
								<Fingerprint />
								<h2>Your identity</h2>
							</div>
							<div
								className={
									"font-light text-xs md:text-sm flex flex-row items-center justify-start gap-1 bg-accent p-2 rounded"
								}
							>
								<p>{userData.id}</p>
								<CopyButton value={userData.id} />
							</div>
						</div>
					</div>
				</div>
				<DialogFooter className={"flex justify-evenly items-center w-full gap-2"}>
					{!refreshOngoing && <Button variant={"outline"} className={"gap-2 px-2"} onClick={()=>doingRefresh()}>
            <RefreshCw />
          </Button>}
					<Button variant={"secondary"} className={"gap-2 px-2"}>
						<Wallet />
						<p>My wallet</p>
					</Button>
					<Button variant={"destructive"} className={"gap-2 px-2"}>
						<Unplug />
						<p>Disconnect</p>
					</Button>
				</DialogFooter>
			</DialogContent>
		</Dialog>
	);
}
