"use client";

import type {
	IApiLoginReq,
	IApiLoginRes,
	IApiRegisterReq,
	IApiRegisterRes, IApiUserAssetsRes,
} from "@/interfaces/api.interface";
import type {IUserData, IUserWallet} from "@/interfaces/userdata.interface";
import ApiRequest from "@/services/apiRequest";
import { useEncodedLocalStorage } from "@/services/localStorage";
import {createContext, type Dispatch, type SetStateAction, useContext, useEffect, useState} from "react";
import {type ICryptoInUserWalletInfo, ICryptoInWalletInfo} from "@/interfaces/crypto.interface";

const [userData, setUserData] = useEncodedLocalStorage<IUserData | null>(
	"user_data",
	null,
);
const UserDataContext = createContext<readonly [IUserData | null, Dispatch<SetStateAction<IUserData | null>>]>([userData, setUserData]);

//TODO Run register task
export async function doRegister(
	registerData: IApiRegisterReq,
): Promise<IApiRegisterRes | null> {
	console.trace(registerData);
	try {
		const ReqRes = await ApiRequest.standard.post.json<IApiRegisterReq, IApiRegisterRes>(
			"auth/signup",
			registerData,
		);
		console.trace(ReqRes.data);
		if (ReqRes.data.user) {
			setUserData(ReqRes.data.user);
		}

		// biome-ignore lint/complexity/noForEach: <explanation>
		ReqRes.data.message?.forEach((err) => console.warn(err));

		return ReqRes.data;
	} catch (error) {
		console.error("Error during registration:", error);
		return null;
	}
}

//TODO Run login task
export async function doLogin(loginData: IApiLoginReq) {
	try {
		const ReqRes = await ApiRequest.standard.post.json<IApiLoginReq, IApiLoginRes>(
			"auth/login",
			loginData,
		);
		console.trace(ReqRes.data);
		//if (ReqRes.data.user) {
		//  setUserData(ReqRes.data.user)
		//}

		// biome-ignore lint/complexity/noForEach: <explanation>
		ReqRes.data.message?.forEach((err) => console.warn(err));
		return ReqRes.data;
	} catch (err) {
		console.error("Error during login:", err);
		return null;
	}
}

//TODO Run disconnect task
export function doDisconnect() {
	if (typeof window !== "undefined") {
		window.localStorage.removeItem("sub");
		return true;
	}
	console.log(
		"Whut ? Why trying to remove an item from the localStorage when runner in SSR ?",
	);
	return false;
}

//TODO Run update user data
export async function refreshUserData() {
	if (!userData) return;

	const isTokenAlive =typeof window !== "undefined" ? window.localStorage.getItem("sub") : null;
	if (!isTokenAlive) return;

	const _reqData = await ApiRequest.authenticated.get.json<IApiUserAssetsRes>("user/my-assets")
	const old_userData = userData
	// biome-ignore lint/style/useConst: <explanation>
	let new_userData: IUserData = old_userData
	let _owned_cryptos: ICryptoInUserWalletInfo[] = []

	if (_reqData.data.UserHasCrypto) {
		_owned_cryptos = _reqData.data.UserHasCrypto.map((el): ICryptoInUserWalletInfo =>{
			return {
				...el.Crypto,
				owned_amount: el.amount
			}
		})
	}

	// biome-ignore lint/suspicious/noAssignInExpressions: <explanation>
	new_userData.wallet = {
		uat: Date.now(),
		update_interval: 30_000,
		owned_cryptos: _owned_cryptos,
	}

	if (Date.now() >= old_userData.wallet.uat + (new_userData.wallet.update_interval / 1_000)) {
		console.log("New update on userData.")
		console.trace(new_userData)
		setUserData(new_userData)
	}

}
